==> istio-model-v1alpha3-6.8.1-sources.jar: io/fabric8/istio/api/analysis/v1alpha1/AnalysisMessageBaseTypeFluent.java <==
package io.fabric8.istio.api.analysis.v1alpha1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class AnalysisMessageBaseTypeFluent<A extends AnalysisMessageBaseTypeFluent<A>> extends BaseFluent<A>{
  public AnalysisMessageBaseTypeFluent() {
  }
  public AnalysisMessageBaseTypeFluent(AnalysisMessageBaseType instance) {
    instance = (instance != null ? instance : new AnalysisMessageBaseType());

    if (instance != null) {
      this.withCode(instance.getCode());
      this.withName(instance.getName());
      this.withCode(instance.getCode());
      this.withName(instance.getName());
    }
  }
  private String code;
  private String name;
  public String getCode() {
    return this.code;
  }
  public A withCode(String code) {
    this.code=code; return (A) this;
  }
  public boolean hasCode() {
    return this.code != null;
  }
  public String getName() {
    return this.name;
  }
  public A withName(String name) {
    this.name=name; return (A) this;
  }
  public boolean hasName() {
    return this.name != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    AnalysisMessageBaseTypeFluent that = (AnalysisMessageBaseTypeFluent) o;
    if (!java.util.Objects.equals(code, that.code)) return false;

    if (!java.util.Objects.equals(name, that.name)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(code,  name,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (code != null) { sb.append("code:"); sb.append(code + ","); }
    if (name != null) { sb.append("name:"); sb.append(name); }
    sb.append("}");
    return sb.toString();
  }
  
}

==> istio-model-v1alpha3-6.9.0-sources.jar: io/fabric8/istio/api/analysis/v1alpha1/AnalysisMessageBaseTypeFluent.java <==
package io.fabric8.istio.api.analysis.v1alpha1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class AnalysisMessageBaseTypeFluent<A extends AnalysisMessageBaseTypeFluent<A>> extends BaseFluent<A>{
  public AnalysisMessageBaseTypeFluent() {
  }
  
  public AnalysisMessageBaseTypeFluent(AnalysisMessageBaseType instance) {
    this.copyInstance(instance);
  }
  private String code;
  private String name;
  
  protected void copyInstance(AnalysisMessageBaseType instance) {
    instance = (instance != null ? instance : new AnalysisMessageBaseType());
  
    if (instance != null) {
        this.withCode(instance.getCode());
        this.withName(instance.getName());
        this.withCode(instance.getCode());
        this.withName(instance.getName());
      }
  }
  
  public String getCode() {
    return this.code;
  }
  
  public A withCode(String code) {
    this.code=code; return (A) this;
  }
  
  public boolean hasCode() {
    return this.code != null;
  }
  
  public String getName() {
    return this.name;
  }
  
  public A withName(String name) {
    this.name=name; return (A) this;
  }
  
  public boolean hasName() {
    return this.name != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    AnalysisMessageBaseTypeFluent that = (AnalysisMessageBaseTypeFluent) o;
    if (!java.util.Objects.equals(code, that.code)) return false;
  
    if (!java.util.Objects.equals(name, that.name)) return false;
  
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(code,  name,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (code != null) { sb.append("code:"); sb.append(code + ","); }
    if (name != null) { sb.append("name:"); sb.append(name); }
    sb.append("}");
    return sb.toString();
  }
  

}
